@@ -1,5 +1,6 @@
-# package
 from pkginfo.bdist import BDist
+from pkginfo.develop import Develop
 from pkginfo.distribution import Distribution
 from pkginfo.installed import Installed
 from pkginfo.sdist import SDist
+from pkginfo.utils import get_metadata
